@@ -157,7 +157,7 @@ def DecompressIP6(ip6, strict=True):
         for c in ip6.lower():
             #if not c in [":", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "a", "b", "c", "d", "e", "f"]:
             if not c in ":0123456789abcdef":
-                raise Exception('%s should consist only of : 0 1 2 3 4 5 6 7 8 9 a b c d e f' %s (ip6))
+                raise Exception('%s should consist only of : 0 1 2 3 4 5 6 7 8 9 a b c d e f' % (ip6))
                 #return None
     else:
         # used for comparison of leases with address pattern - X replace the dynamic part of the address
